@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <locationinformation.h>
+#include "locationinformation.h"
 
 #include <QtTest/qtest.h>
 
@@ -56,7 +56,23 @@ private Q_SLOTS:
         QCOMPARE(info.drivingSide(), KItinerary::KnowledgeDb::DrivingSide::Right);
         QCOMPARE(info.powerPlugCompatibility(), LocationInformation::Incompatible);
         QVERIFY(info.currencyDiffers());
-        QCOMPARE(info.currencyCode(), QLatin1String("EUR"));
+        QCOMPARE(info.currencyCode(), QLatin1StringView("EUR"));
+    }
+
+    void testDstChange()
+    {
+        LocationInformation l;
+        l.setTimeZone(QTimeZone("Europe/Berlin"), QDateTime{{2024, 3, 29}, {2, 0}, QTimeZone("Europe/Berlin")});
+        l.setTimeZone(QTimeZone("Europe/Berlin"), QDateTime{{2024, 3, 31}, {3, 0}, QTimeZone("Europe/Berlin")});
+        QCOMPARE(l.timeZoneDiffers(), true);
+        QCOMPARE(l.dstDiffers(), true);
+        QCOMPARE(l.isDst(), true);
+        QCOMPARE(l.timeZoneOffsetDelta(), 3600);
+        l.setTimeZone(QTimeZone("Europe/Berlin"), QDateTime{{2024, 10, 27}, {2, 0}, QTimeZone("Europe/Berlin")});
+        QCOMPARE(l.timeZoneDiffers(), true);
+        QCOMPARE(l.dstDiffers(), true);
+        QCOMPARE(l.isDst(), false);
+        QCOMPARE(l.timeZoneOffsetDelta(), -3600);
     }
 };
 
