@@ -10,15 +10,15 @@
 #include "applicationcontroller.h"
 #include "importcontroller.h"
 #include "reservationmanager.h"
-#include "transfermanager.h"
 #include "timelinemodel.h"
+#include "transfermanager.h"
 #include "tripgroupmanager.h"
 #include "tripgroupproxymodel.h"
 
 #include <QAbstractItemModelTester>
-#include <QtTest/qtest.h>
 #include <QSignalSpy>
 #include <QStandardPaths>
+#include <QtTest/qtest.h>
 
 using namespace Qt::Literals;
 
@@ -70,7 +70,9 @@ private Q_SLOTS:
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setCurrentDateTime(QDateTime({1996, 10, 14}, {12, 34}));
         model.setReservationManager(&resMgr);
+        model.setTransferManager(&transferMgr);
         model.setTripGroupManager(&groupMgr);
+        Test::waitForReset(&model);
 
         TripGroupProxyModel proxy;
         QAbstractItemModelTester tester(&proxy);
@@ -133,11 +135,13 @@ private Q_SLOTS:
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setCurrentDateTime(QDateTime({2017, 9, 9}, {12, 34}));
         model.setReservationManager(&resMgr);
+        model.setTransferManager(&transferMgr);
         model.setTripGroupManager(&groupMgr);
 
         TripGroupProxyModel proxy;
         QAbstractItemModelTester tester(&proxy);
         proxy.setSourceModel(&model);
+        Test::waitForReset(&model);
 
         // future event, should be expanded
         ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/current-r0.model"));
@@ -162,7 +166,6 @@ private Q_SLOTS:
         QCOMPARE(proxy.rowCount(), 3);
         QVERIFY(vp2.verify(&proxy));
     }
-
 };
 QTEST_GUILESS_MAIN(TripGroupProxyTest)
 
