@@ -6,11 +6,11 @@
 #ifndef ITINERARY_ACTIVITY_H
 #define ITINERARY_ACTIVITY_H
 
-#include "kandroidextras/jnitypes.h"
+#include "kandroidextras/androidtypes.h"
+#include "kandroidextras/javatypes.h"
 #include "kandroidextras/jnimethod.h"
 #include "kandroidextras/jniproperty.h"
-#include "kandroidextras/javatypes.h"
-#include "kandroidextras/androidtypes.h"
+#include "kandroidextras/jnitypes.h"
 #include "kandroidextras/uri.h"
 
 #include <QCoreApplication>
@@ -18,13 +18,15 @@
 JNI_TYPE(org, kde, itinerary, Activity)
 
 /** Interface to the Java Activity class. */
-class ItineraryActivity {
+class ItineraryActivity
+{
     JNI_UNMANAGED_OBJECT(ItineraryActivity, org::kde::itinerary::Activity)
 public:
     JNI_METHOD(KAndroidExtras::Jni::Array<KAndroidExtras::java::lang::String>, attachmentsForIntent, KAndroidExtras::android::content::Intent)
     JNI_METHOD(KAndroidExtras::android::net::Uri, openDocument, KAndroidExtras::java::lang::String)
 private:
-    inline QJniObject jniHandle() const {
+    inline QJniObject jniHandle() const
+    {
         return QNativeInterface::QAndroidApplication::context();
     }
 };
