@@ -8,6 +8,7 @@
 #define APPLICATIONCONTROLLER_H
 
 #include <QObject>
+#include <QVariantMap>
 
 #include <memory>
 
@@ -22,12 +23,14 @@ class ReservationManager;
 class TransferManager;
 class TripGroupManager;
 
-namespace KItinerary {
+namespace KItinerary
+{
 class ExtractorDocumentNode;
 class File;
 }
 
-namespace KAndroidExtras {
+namespace KAndroidExtras
+{
 class Intent;
 }
 
@@ -41,15 +44,21 @@ class ApplicationController : public QObject
     Q_PROPERTY(QString extractorCapabilities READ extractorCapabilities CONSTANT)
     Q_PROPERTY(QVariant aboutData READ aboutData CONSTANT)
     Q_PROPERTY(QString userAgent READ userAgent CONSTANT)
+
+    /** The current trip group context, ie. the currently looked at trip group.
+     *  Not to be confused with the current trip group, ie. the one happening now.
+     */
+    Q_PROPERTY(QString contextTripGroupId MEMBER m_contextTripGroupId WRITE setContextTripGroupId NOTIFY contextTripGroupIdChanged)
+
     Q_PROPERTY(bool hasHealthCertificateSupport READ hasHealthCertificateSupport CONSTANT)
     Q_PROPERTY(HealthCertificateManager *healthCertificateManager READ healthCertificateManager CONSTANT)
 public:
     explicit ApplicationController(QObject *parent = nullptr);
     ~ApplicationController() override;
 
-    void setNetworkAccessManagerFactory(const std::function<QNetworkAccessManager*()> &namFactory);
+    void setNetworkAccessManagerFactory(const std::function<QNetworkAccessManager *()> &namFactory);
 
-    void requestOpenPage(const QString &page);
+    void requestOpenPage(const QString &page, const QVariantMap &properties = {});
 
     void setReservationManager(ReservationManager *resMgr);
     void setPkPassManager(PkPassManager *pkPassMgr);
@@ -62,11 +71,14 @@ public:
 
     // page navigation intents
     void handleIntent(const KAndroidExtras::Intent &intent);
+    void handleGeoUrl(const QUrl &url);
 
     // data import
     Q_INVOKABLE void commitImport(ImportController *importController);
+    /** Add a newly created reservation and add it to a trip group. */
+    Q_INVOKABLE [[nodiscard]] QString addNewReservation(const QVariant &res, const QString &tgId);
 
-    static ApplicationController* instance();
+    static ApplicationController *instance();
 
     // data export
     Q_INVOKABLE void exportToFile(const QUrl &url);
@@ -93,17 +105,21 @@ public:
     bool hasHealthCertificateSupport() const;
     HealthCertificateManager *healthCertificateManager() const;
 
+    void setContextTripGroupId(const QString &contextTripGroupId);
+
 Q_SIGNALS:
     /** Human readable information message to be shown as passive notification. */
     void infoMessage(const QString &msg);
 
-    void openPageRequested(const QString &page);
+    void openPageRequested(const QString &page, const QVariantMap &properties);
 
     /** Edit and add a new reservation. */
     void editNewHotelReservation(const QVariant &res);
     void editNewRestaurantReservation(const QVariant &res);
     void editNewEventReservation(const QVariant &res);
 
+    void contextTripGroupIdChanged();
+
 private:
     bool importBundle(KItinerary::File *file);
     void pkPassUpdated(const QString &passId);
@@ -124,7 +140,9 @@ private:
     TripGroupManager *m_tripGroupMgr = nullptr;
     PassManager *m_passMgr = nullptr;
     mutable HealthCertificateManager *m_healthCertMgr = nullptr;
-    std::function<QNetworkAccessManager*()> m_namFactory;
+    std::function<QNetworkAccessManager *()> m_namFactory;
+
+    QString m_contextTripGroupId;
 
     std::unique_ptr<QTemporaryDir> m_tempDir;
     bool m_importLock = false;
