@@ -9,8 +9,8 @@
 #include "logging.h"
 
 #include "applicationcontroller.h"
-#include "countrysubdivisionmodel.h"
 #include "clipboard.h"
+#include "countrysubdivisionmodel.h"
 #include "developmentmodecontroller.h"
 #include "documentmanager.h"
 #include "documentsmodel.h"
@@ -31,9 +31,9 @@
 #include "notificationconfigcontroller.h"
 #include "onlineticketimporter.h"
 #include "passmanager.h"
-#include "pkpassmanager.h"
 #include "permissionmanager.h"
 #include "pkpassimageprovider.h"
+#include "pkpassmanager.h"
 #include "publictransport.h"
 #include "reservationhelper.h"
 #include "reservationmanager.h"
@@ -49,7 +49,9 @@
 #include "transfermanager.h"
 #include "tripgroupcontroller.h"
 #include "tripgroupfilterproxymodel.h"
+#include "tripgrouplocationmodel.h"
 #include "tripgroupmanager.h"
+#include "tripgroupmapmodel.h"
 #include "tripgroupmodel.h"
 #include "tripgroupproxymodel.h"
 #include "tripgroupsplitmodel.h"
@@ -58,24 +60,21 @@
 #include "weatherforecastmodel.h"
 
 #if HAVE_MATRIX
-#include "matrix/matrixroomsmodel.h"
 #include "matrix/matrixbeacon.h"
+#include "matrix/matrixroomsmodel.h"
 #endif
 
 #include "weatherforecastmanager.h"
 
-#include "calendarlistmodel.h"
-#include <KCalendarCore/CalendarPluginLoader>
-
 #include <KItinerary/CountryDb>
 #include <KItinerary/DocumentUtil>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/PriceUtil>
 #include <KItinerary/Ticket>
 
-#include <KPkPass/Field>
 #include <KPkPass/Barcode>
 #include <KPkPass/BoardingPass>
+#include <KPkPass/Field>
 
 #ifndef Q_OS_ANDROID
 #include <KDBusService>
@@ -91,12 +90,10 @@
 #if HAVE_KCRASH
 #include <KCrash>
 #endif
-#include <kcontacts_version.h>
-#include <KContacts/AddressFormat>
 
-#include <QQuickStyle>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QQuickStyle>
 
 #ifdef Q_OS_ANDROID
 #include "kandroidextras/activity.h"
@@ -125,32 +122,6 @@ class MatrixBeaconStub : public QObject
 };
 #endif
 
-void registerKContactsTypes()
-{
-#if KCONTACTS_VERSION < QT_VERSION_CHECK(6, 3, 0)
-    // ### this should move into a real QML plugin for KContacts
-    qmlRegisterUncreatableMetaObject(KContacts::staticMetaObject, "org.kde.contacts", 1, 0, "KContacts", {});
-    qmlRegisterSingletonType("org.kde.contacts", 1, 0, "AddressFormatRepository", [](QQmlEngine *, QJSEngine *jsEngine) -> QJSValue {
-        return jsEngine->toScriptValue(KContacts::AddressFormatRepository());
-    });
-    qRegisterMetaType<KContacts::AddressFormat>();
-    qRegisterMetaType<KContacts::AddressFormatElement>();
-    qRegisterMetaType<KContacts::AddressFormatRepository>();
-    qRegisterMetaType<KContacts::AddressFormatPreference>();
-    qRegisterMetaType<KContacts::AddressFormatScriptPreference>();
-#endif
-}
-
-void registerKCalendarCoreTypes()
-{
-    // ### this should move into a QML plugin of KCalendarCore
-    qmlRegisterUncreatableMetaObject(KCalendarCore::staticMetaObject, "internal.org.kde.kcalendarcore", 1, 0, "KCalendarCore", {});
-    qmlRegisterType<KCalendarCoreExtras::CalendarListModel>("internal.org.kde.kcalendarcore", 1, 0, "CalendarListModel");
-    qmlRegisterSingletonType("internal.org.kde.kcalendarcore", 1, 0, "CalendarPluginLoader", [](QQmlEngine *, QJSEngine *jsEngine) -> QJSValue {
-        return jsEngine->toScriptValue(KCalendarCore::CalendarPluginLoader());
-    });
-}
-
 void registerKPkPassTypes()
 {
     qmlRegisterUncreatableMetaObject(KPkPass::Barcode::staticMetaObject, "org.kde.pkpass", 1, 0, "Barcode", {});
@@ -164,24 +135,23 @@ void registerKItineraryTypes()
     qRegisterMetaType<KItinerary::KnowledgeDb::DrivingSide>();
     qmlRegisterUncreatableMetaObject(KItinerary::Ticket::staticMetaObject, "org.kde.kitinerary", 1, 0, "Ticket", {});
     qmlRegisterUncreatableMetaObject(KItinerary::KnowledgeDb::staticMetaObject, "org.kde.kitinerary", 1, 0, "KnowledgeDb", {});
-    qmlRegisterSingletonType("org.kde.itinerary", 1, 0, "PriceUtil", [](QQmlEngine*, QJSEngine *engine) -> QJSValue {
+    qmlRegisterSingletonType("org.kde.itinerary", 1, 0, "PriceUtil", [](QQmlEngine *, QJSEngine *engine) -> QJSValue {
         return engine->toScriptValue(KItinerary::PriceUtil());
     });
 }
 
 void registerApplicationTypes()
 {
-    qRegisterMetaType<ReservationManager*>();
+    qRegisterMetaType<ReservationManager *>();
     qRegisterMetaType<Transfer::Alignment>();
-    qRegisterMetaType<TripGroupManager*>();
+    qRegisterMetaType<TripGroupManager *>();
     qRegisterMetaType<WeatherForecast>();
     qRegisterMetaType<Permission::Permission>();
-    qRegisterMetaType<HealthCertificateManager*>();
+    qRegisterMetaType<HealthCertificateManager *>();
 
     qmlRegisterUncreatableMetaObject(LocationInformation::staticMetaObject, "org.kde.itinerary", 1, 0, "LocationInformation", {});
     qmlRegisterUncreatableMetaObject(StatisticsItem::staticMetaObject, "org.kde.itinerary", 1, 0, "StatisticsItem", {});
     qmlRegisterUncreatableMetaObject(TimelineElement::staticMetaObject, "org.kde.itinerary", 1, 0, "TimelineElement", {});
-    qmlRegisterUncreatableType<TimelineModel>("org.kde.itinerary", 1, 0, "TimelineModel", {});
     qmlRegisterUncreatableMetaObject(Transfer::staticMetaObject, "org.kde.itinerary", 1, 0, "Transfer", {});
 
     qmlRegisterUncreatableMetaObject(Permission::staticMetaObject, "org.kde.itinerary", 1, 0, "Permission", {});
@@ -197,10 +167,14 @@ void registerApplicationTypes()
     qmlRegisterType<StatisticsTimeRangeModel>("org.kde.itinerary", 1, 0, "StatisticsTimeRangeModel");
     qmlRegisterType<TicketTokenModel>("org.kde.itinerary", 1, 0, "TicketTokenModel");
     qmlRegisterType<TimelineDelegateController>("org.kde.itinerary", 1, 0, "TimelineDelegateController");
+    qmlRegisterType<TimelineModel>("org.kde.itinerary", 1, 0, "TimelineModel");
     qmlRegisterType<TimelineSectionDelegateController>("org.kde.itinerary", 1, 0, "TimelineSectionDelegateController");
     qmlRegisterType<TransferDelegateController>("org.kde.itinerary", 1, 0, "TransferDelegateController");
     qmlRegisterType<TripGroupController>("org.kde.itinerary", 1, 0, "TripGroupController");
     qmlRegisterType<TripGroupFilterProxyModel>("org.kde.itinerary", 1, 0, "TripGroupFilterProxyModel");
+    qmlRegisterType<TripGroupLocationModel>("org.kde.itinerary", 1, 0, "TripGroupLocationModel");
+    qmlRegisterType<TripGroupMapModel>("org.kde.itinerary", 1, 0, "TripGroupMapModel");
+    qmlRegisterType<TripGroupProxyModel>("org.kde.itinerary", 1, 0, "TripGroupProxyModel");
     qmlRegisterType<TripGroupSplitModel>("org.kde.itinerary", 1, 0, "TripGroupSplitModel");
     qmlRegisterType<WeatherForecastModel>("org.kde.itinerary", 1, 0, "WeatherForecastModel");
 #if HAVE_MATRIX
@@ -221,8 +195,6 @@ static TransferManager *s_tranferManager = nullptr;
 static TripGroupManager *s_tripGroupManager = nullptr;
 static LiveDataManager *s_liveDataMnager = nullptr;
 static WeatherForecastManager *s_weatherForecastManager = nullptr;
-static TimelineModel *s_timelineModel = nullptr;
-static TripGroupProxyModel *s_tripGroupProxyModel = nullptr;
 static MapDownloadManager *s_mapDownloadManager = nullptr;
 static PassManager *s_passManager = nullptr;
 static MatrixController *s_matrixController = nullptr;
@@ -230,12 +202,11 @@ static ImportController *s_importController = nullptr;
 static TripGroupModel *s_tripGroupModel = nullptr;
 static TraewellingController *s_traewellingController = nullptr;
 
-#define REGISTER_SINGLETON_INSTANCE(Class, Instance) \
-    qmlRegisterSingletonInstance<Class>("org.kde.itinerary", 1, 0, #Class, Instance);
+#define REGISTER_SINGLETON_INSTANCE(Class, Instance) qmlRegisterSingletonInstance<Class>("org.kde.itinerary", 1, 0, #Class, Instance);
 
-#define REGISTER_SINGLETON_GADGET_FACTORY(Class) \
-    qmlRegisterSingletonType("org.kde.itinerary", 1, 0, #Class, [](QQmlEngine*, QJSEngine *engine) -> QJSValue { \
-        return engine->toScriptValue(Class()); \
+#define REGISTER_SINGLETON_GADGET_FACTORY(Class)                                                                                                               \
+    qmlRegisterSingletonType("org.kde.itinerary", 1, 0, #Class, [](QQmlEngine *, QJSEngine *engine) -> QJSValue {                                              \
+        return engine->toScriptValue(Class());                                                                                                                 \
     });
 
 void registerApplicationSingletons()
@@ -250,8 +221,6 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_INSTANCE(TripGroupManager, s_tripGroupManager)
     REGISTER_SINGLETON_INSTANCE(LiveDataManager, s_liveDataMnager)
     REGISTER_SINGLETON_INSTANCE(WeatherForecastManager, s_weatherForecastManager)
-    REGISTER_SINGLETON_INSTANCE(TimelineModel, s_timelineModel)
-    REGISTER_SINGLETON_INSTANCE(TripGroupProxyModel, s_tripGroupProxyModel)
     REGISTER_SINGLETON_INSTANCE(MapDownloadManager, s_mapDownloadManager)
     REGISTER_SINGLETON_INSTANCE(PassManager, s_passManager)
     REGISTER_SINGLETON_INSTANCE(MatrixController, s_matrixController);
@@ -294,10 +263,13 @@ static QNetworkAccessManager *namFactory()
     return s_nam;
 }
 
-void handleCommandLineArguments(ApplicationController *appController, ImportController *importController, const QStringList &args, bool isTemporary, const QString &page)
+void handleCommandLineArguments(ApplicationController *appController,
+                                ImportController *importController,
+                                const QStringList &args,
+                                bool isTemporary,
+                                const QString &page)
 {
     for (const auto &file : args) {
-        importController->setAutoCommitEnablted(!s_settings->developmentMode());
         const auto localUrl = QUrl::fromLocalFile(file);
         if (QFile::exists(localUrl.toLocalFile())) {
             importController->importFromUrl(localUrl);
@@ -305,7 +277,13 @@ void handleCommandLineArguments(ApplicationController *appController, ImportCont
                 QFile::remove(localUrl.toLocalFile());
             }
         } else {
-            importController->importFromUrl(QUrl::fromUserInput(file));
+            const auto url = QUrl::fromUserInput(file);
+            if (url.scheme() == "geo"_L1) {
+                // User wants to go there
+                appController->handleGeoUrl(url);
+            } else {
+                importController->importFromUrl(QUrl::fromUserInput(file));
+            }
         }
     }
 
@@ -420,19 +398,6 @@ int main(int argc, char **argv)
     tripGroupModel.setTripGroupManager(&tripGroupMgr);
     s_tripGroupModel = &tripGroupModel;
 
-    TimelineModel timelineModel;
-    timelineModel.setHomeCountryIsoCode(settings.homeCountryIsoCode());
-    timelineModel.setReservationManager(&resMgr);
-    timelineModel.setWeatherForecastManager(&weatherForecastMgr);
-    timelineModel.setTransferManager(&transferManager);
-    timelineModel.setTripGroupManager(&tripGroupMgr);
-    QObject::connect(&settings, &Settings::homeCountryIsoCodeChanged, &timelineModel, &TimelineModel::setHomeCountryIsoCode);
-    s_timelineModel = &timelineModel;
-
-    TripGroupProxyModel tripGroupProxy;
-    tripGroupProxy.setSourceModel(&timelineModel);
-    s_tripGroupProxyModel = &tripGroupProxy;
-
     MapDownloadManager mapDownloadMgr;
     mapDownloadMgr.setReservationManager(&resMgr);
     mapDownloadMgr.setAutomaticDownloadEnabled(s_settings->preloadMapData());
@@ -465,6 +430,7 @@ int main(int argc, char **argv)
     appController.setLiveDataManager(&liveDataMgr);
     appController.setTripGroupManager(&tripGroupMgr);
     appController.setPassManager(&passMgr);
+    appController.setContextTripGroupId(tripGroupModel.currentTripGroupId());
 #if !defined(Q_OS_ANDROID) && !defined(Q_OS_HAIKU)
     QObject::connect(&service, &KDBusService::activateRequested, [&](const QStringList &args, const QString &workingDir) {
         qCDebug(Log) << "remote activation" << args << workingDir;
@@ -485,8 +451,6 @@ int main(int argc, char **argv)
 
     OnlineTicketImporter::setNetworkAccessManagerFactory(namFactory);
 
-    registerKContactsTypes();
-    registerKCalendarCoreTypes();
     registerKPkPassTypes();
     registerKItineraryTypes();
     registerApplicationTypes();
@@ -495,23 +459,25 @@ int main(int argc, char **argv)
     QQmlApplicationEngine engine;
 
     auto pkPassImageProvider = new PkPassImageProvider;
-    pkPassImageProvider->registerPassProvider([&pkPassMgr](const QString &passTypeId, const QString &serialNum) -> KPkPass::Pass* {
+    pkPassImageProvider->registerPassProvider([&pkPassMgr](const QString &passTypeId, const QString &serialNum) -> KPkPass::Pass * {
         return pkPassMgr.pass(passTypeId + '/'_L1 + QString::fromUtf8(serialNum.toUtf8().toBase64(QByteArray::Base64UrlEncoding)));
     });
-    pkPassImageProvider->registerPassProvider([&importController](const QString &passTypeId, const QString &serialNum) -> KPkPass::Pass* {
-        if (const auto it = importController.pkPasses().find(KItinerary::DocumentUtil::idForPkPass(passTypeId, serialNum)); it != importController.pkPasses().end()) {
+    pkPassImageProvider->registerPassProvider([&importController](const QString &passTypeId, const QString &serialNum) -> KPkPass::Pass * {
+        if (const auto it = importController.pkPasses().find(KItinerary::DocumentUtil::idForPkPass(passTypeId, serialNum));
+            it != importController.pkPasses().end()) {
             if (!(*it).second.pass) {
                 (*it).second.pass.reset(KPkPass::Pass::fromData((*it).second.data));
             }
             return (*it).second.pass.get();
         }
         return nullptr;
-    });    engine.addImageProvider(QStringLiteral("org.kde.pkpass"), pkPassImageProvider);
+    });
+    engine.addImageProvider(QStringLiteral("org.kde.pkpass"), pkPassImageProvider);
 
     auto l10nContext = new KLocalizedContext(&engine);
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine.rootContext()->setContextObject(l10nContext);
-    engine.load(QStringLiteral("qrc:/qt/qml/org/kde/itinerary/main.qml"));
+    engine.loadFromModule("org.kde.itinerary", "Main");
 
     // Exit on QML load error.
     if (engine.rootObjects().isEmpty()) {
