@@ -10,8 +10,8 @@
 #include "logging.h"
 #include "reservationhelper.h"
 
-#include <KItinerary/ExtractorPostprocessor>
 #include <KItinerary/Event>
+#include <KItinerary/ExtractorPostprocessor>
 #include <KItinerary/Flight>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/MergeUtil>
@@ -34,8 +34,9 @@
 #include <QUuid>
 
 using namespace KItinerary;
+using namespace Qt::Literals;
 
-ReservationManager::ReservationManager(QObject* parent)
+ReservationManager::ReservationManager(QObject *parent)
     : QObject(parent)
     , m_validator(ReservationManager::validator())
 {
@@ -49,17 +50,15 @@ ReservationManager::~ReservationManager() = default;
 KItinerary::ExtractorValidator ReservationManager::validator()
 {
     KItinerary::ExtractorValidator v;
-    v.setAcceptedTypes<
-        BoatReservation,
-        BusReservation,
-        EventReservation,
-        FlightReservation,
-        FoodEstablishmentReservation,
-        LodgingReservation,
-        RentalCarReservation,
-        TrainReservation,
-        TouristAttractionVisit
-    >();
+    v.setAcceptedTypes<BoatReservation,
+                       BusReservation,
+                       EventReservation,
+                       FlightReservation,
+                       FoodEstablishmentReservation,
+                       LodgingReservation,
+                       RentalCarReservation,
+                       TrainReservation,
+                       TouristAttractionVisit>();
     return v;
 }
 
@@ -73,7 +72,7 @@ bool ReservationManager::hasBatch(const QString &batchId) const
     return m_batchToResMap.contains(batchId);
 }
 
-QVariant ReservationManager::reservation(const QString& id) const
+QVariant ReservationManager::reservation(const QString &id) const
 {
     if (id.isEmpty()) {
         return {};
@@ -157,7 +156,9 @@ QString ReservationManager::addReservation(const QVariant &res, const QString &r
 {
     // deal with partial updates
     if (!m_validator.isValidElement(res)) {
-        const auto cleanup = qScopeGuard([this] { m_validator.setAcceptOnlyCompleteElements(true); });
+        const auto cleanup = qScopeGuard([this] {
+            m_validator.setAcceptOnlyCompleteElements(true);
+        });
         m_validator.setAcceptOnlyCompleteElements(false);
         if (m_validator.isValidElement(res)) {
             const auto ids = applyPartialUpdate(res);
@@ -230,9 +231,10 @@ QString ReservationManager::addReservation(const QVariant &res, const QString &r
     return resId;
 }
 
-void ReservationManager::addReservationWithPostProcessing(const QVariant &resData)
+QString ReservationManager::addReservationWithPostProcessing(const QVariant &resData)
 {
-    addReservationsWithPostProcessing({resData});
+    const auto l = addReservationsWithPostProcessing({resData});
+    return !l.isEmpty() ? l.at(0) : QString();
 }
 
 void ReservationManager::updateReservation(const QString &resId, const QVariant &res)
@@ -259,18 +261,20 @@ void ReservationManager::storeReservation(const QString &resId, const QVariant &
     m_reservations.insert(resId, res);
 }
 
-void ReservationManager::removeReservation(const QString& id)
+void ReservationManager::removeReservation(const QString &id)
 {
     const auto batchId = m_resToBatchMap.value(id);
     removeFromBatch(id, batchId);
 
     const QString basePath = reservationsBasePath();
-    QFile::remove(basePath + QLatin1Char('/') + id + QLatin1StringView(".jsonld"));
+    if (!QFile::remove(basePath + '/'_L1 + id + ".jsonld"_L1)) {
+        qCWarning(Log) << "Failed to remove file:" << id;
+    }
     Q_EMIT reservationRemoved(id);
     m_reservations.remove(id);
 }
 
-const std::vector<QString>& ReservationManager::batches() const
+const std::vector<QString> &ReservationManager::batches() const
 {
     return m_batches;
 }
@@ -307,6 +311,8 @@ void ReservationManager::loadBatches()
         return;
     }
 
+    QStringList batchesToRemove; // broken stuff detected during loading
+
     for (QDirIterator it(base, QDir::NoDotAndDotDot | QDir::Files); it.hasNext();) {
         it.next();
         QFile batchFile(it.filePath());
@@ -321,6 +327,11 @@ void ReservationManager::loadBatches()
         const auto batchVal = JsonIO::read(batchFile.readAll());
         const auto top = batchVal.toObject();
         const auto resArray = top.value(QLatin1StringView("elements")).toArray();
+        if (resArray.isEmpty()) {
+            batchesToRemove.push_back(batchId);
+            continue;
+        }
+
         QStringList l;
         l.reserve(resArray.size());
         for (const auto &v : resArray) {
@@ -334,6 +345,10 @@ void ReservationManager::loadBatches()
     std::sort(m_batches.begin(), m_batches.end(), [this](const auto &lhs, const auto &rhs) {
         return SortUtil::isBefore(reservation(lhs), reservation(rhs));
     });
+
+    for (const auto &batchId : batchesToRemove) {
+        storeRemoveBatch(batchId);
+    }
 }
 
 void ReservationManager::storeBatch(const QString &batchId) const
@@ -358,7 +373,9 @@ void ReservationManager::storeBatch(const QString &batchId) const
 void ReservationManager::storeRemoveBatch(const QString &batchId) const
 {
     const QString path = batchesBasePath() + batchId + QLatin1StringView(".json");
-    QFile::remove(path);
+    if (!QFile::remove(path)) {
+        qCWarning(Log) << "Failed to remove file:" << path;
+    }
 }
 
 void ReservationManager::initialBatchCreate()
@@ -379,7 +396,24 @@ void ReservationManager::initialBatchCreate()
 
 void ReservationManager::updateBatch(const QString &resId, const QVariant &newRes, const QVariant &oldRes)
 {
+    bool sortOrderInvalid = false;
     const auto oldBatchId = batchForReservation(resId);
+    if (oldBatchId == resId) {
+        const auto it = std::find(m_batches.begin(), m_batches.end(), resId);
+        if (it != m_batches.begin() && it != m_batches.end()) {
+            sortOrderInvalid |= SortUtil::startDateTime(reservation(*std::prev(it))) >= SortUtil::startDateTime(reservation(*it));
+        }
+        if (it != m_batches.end() && std::distance(it, m_batches.end()) > 1) {
+            sortOrderInvalid |= SortUtil::startDateTime(reservation(*it)) >= SortUtil::startDateTime(reservation(*std::next(it)));
+        }
+        if (!sortOrderInvalid && m_batchToResMap.value(resId).size() == 1) {
+            Q_EMIT batchContentChanged(resId);
+            return;
+        }
+        if (sortOrderInvalid) { // otherwise the lower_bound search below doesn't work!
+            removeFromBatch(resId, oldBatchId);
+        }
+    }
     QString newBatchId;
 
     // find the destination batch
@@ -406,7 +440,9 @@ void ReservationManager::updateBatch(const QString &resId, const QVariant &newRe
 
     // move us out of the old batch
     // WARNING: beginIt will become invalid after this!
-    removeFromBatch(resId, oldBatchId);
+    if (!sortOrderInvalid) {
+        removeFromBatch(resId, oldBatchId);
+    }
 
     // insert us into the new batch
     if (newBatchId.isEmpty()) {
@@ -569,7 +605,7 @@ QString ReservationManager::previousBatch(const QString &batchId) const
     return *(it - 1);
 }
 
-QString ReservationManager::nextBatch(const QString& batchId) const
+QString ReservationManager::nextBatch(const QString &batchId) const
 {
     // ### this can be optimized by relying on m_batches being sorted by start date
     const auto it = std::find(m_batches.begin(), m_batches.end(), batchId);
