@@ -5,9 +5,12 @@
 */
 
 #include "statisticsmodel.h"
-#include "locationhelper.h"
+#include "livedatamanager.h"
 #include "localizer.h"
+#include "locationhelper.h"
 #include "reservationmanager.h"
+#include "transfermanager.h"
+#include "tripgroup.h"
 #include "tripgroupmanager.h"
 
 #include <KItinerary/LocationUtil>
@@ -15,6 +18,9 @@
 #include <KItinerary/Reservation>
 #include <KItinerary/SortUtil>
 
+#include <KPublicTransport/Journey>
+#include <KPublicTransport/RentalVehicle>
+
 #include <KCountry>
 #include <KLocalizedString>
 
@@ -45,7 +51,7 @@ StatisticsModel::StatisticsModel(QObject *parent)
 
 StatisticsModel::~StatisticsModel() = default;
 
-ReservationManager* StatisticsModel::reservationManager() const
+ReservationManager *StatisticsModel::reservationManager() const
 {
     return m_resMgr;
 }
@@ -60,12 +66,12 @@ void StatisticsModel::setReservationManager(ReservationManager *resMgr)
     Q_EMIT setupChanged();
 }
 
-TripGroupManager* StatisticsModel::tripGroupManager() const
+TripGroupManager *StatisticsModel::tripGroupManager() const
 {
     return m_tripGroupMgr;
 }
 
-void StatisticsModel::setTripGroupManager(TripGroupManager* tripGroupMgr)
+void StatisticsModel::setTripGroupManager(TripGroupManager *tripGroupMgr)
 {
     if (m_tripGroupMgr == tripGroupMgr) {
         return;
@@ -75,6 +81,16 @@ void StatisticsModel::setTripGroupManager(TripGroupManager* tripGroupMgr)
     Q_EMIT setupChanged();
 }
 
+void StatisticsModel::setTransferManager(TransferManager *transferMgr)
+{
+    if (m_transferMgr == transferMgr) {
+        return;
+    }
+    m_transferMgr = transferMgr;
+    connect(m_transferMgr, &TransferManager::transferAdded, this, &StatisticsModel::recompute);
+    Q_EMIT setupChanged();
+}
+
 void StatisticsModel::setTimeRange(const QDate &begin, const QDate &end)
 {
     if (m_begin == begin && end == m_end) {
@@ -194,35 +210,23 @@ StatisticsItem StatisticsModel::boatCO2() const
     return StatisticsItem(i18n("CO₂"), Localizer::formatWeight(m_statData[Boat][CO2]), trend(Boat, CO2), m_hasData[Boat]);
 }
 
-StatisticsModel::AggregateType StatisticsModel::typeForReservation(const QVariant &res) const
+StatisticsModel::AggregateType StatisticsModel::typeForReservation(const QVariant &res)
 {
     if (JsonLd::isA<FlightReservation>(res)) {
         return Flight;
-    } else if (JsonLd::isA<TrainReservation>(res)) {
+    }
+    if (JsonLd::isA<TrainReservation>(res)) {
         return Train;
-    } else if (JsonLd::isA<BusReservation>(res)) {
+    }
+    if (JsonLd::isA<BusReservation>(res)) {
         return Bus;
-    } else if (JsonLd::isA<BoatReservation>(res)) {
+    }
+    if (JsonLd::isA<BoatReservation>(res)) {
         return Boat;
     }
     return Car;
 }
 
-static int distance(const QVariant &res)
-{
-    const auto dep = LocationUtil::departureLocation(res);
-    const auto arr = LocationUtil::arrivalLocation(res);
-    if (dep.isNull() || arr.isNull()) {
-        return 0;
-    }
-    const auto depGeo = LocationUtil::geo(dep);
-    const auto arrGeo = LocationUtil::geo(arr);
-    if (!depGeo.isValid() || !arrGeo.isValid()) {
-        return 0;
-    }
-    return std::max(0, LocationUtil::distance(depGeo, arrGeo));
-}
-
 // from https://en.wikipedia.org/wiki/Environmental_impact_of_transport
 static const int emissionPerKm[] = {
     0,
@@ -233,16 +237,27 @@ static const int emissionPerKm[] = {
     113, // ferry
 };
 
-int StatisticsModel::co2emission(StatisticsModel::AggregateType type, int distance) const
+double StatisticsModel::co2emission(StatisticsModel::AggregateType type, double distance)
 {
     return distance * emissionPerKm[type];
 }
 
-void StatisticsModel::computeStats(const QVariant& res, int (&statData)[AGGREGATE_TYPE_COUNT][STAT_TYPE_COUNT])
+double StatisticsModel::co2Emission(const QVariant &res)
+{
+    return co2emission(typeForReservation(res), LocationHelper::distance(res) / 1000.0);
+}
+
+void StatisticsModel::computeStats(const QString &resId, const QVariant &res, int (&statData)[AGGREGATE_TYPE_COUNT][STAT_TYPE_COUNT])
 {
     const auto type = typeForReservation(res);
-    const auto dist = distance(res);
-    const auto co2 = co2emission(type, dist / 1000);
+    double dist = LocationHelper::distance(res);
+    double co2 = co2emission(type, dist / 1000.0);
+
+    // live data is more accurate when present
+    if (const auto jny = m_transferMgr->liveDataManager()->journey(resId); jny.mode() != KPublicTransport::JourneySection::Invalid) {
+        dist = std::max<double>(dist, jny.distance()); // we cannot possibly get shorter than the direct distance
+        co2 = jny.co2Emission();
+    }
 
     statData[type][TripCount]++;
     statData[type][Distance] += dist;
@@ -253,6 +268,71 @@ void StatisticsModel::computeStats(const QVariant& res, int (&statData)[AGGREGAT
     statData[Total][CO2] += co2;
 }
 
+void StatisticsModel::computeStats(const KPublicTransport::Journey &journey, int (&statData)[AGGREGATE_TYPE_COUNT][STAT_TYPE_COUNT])
+{
+    struct {
+        KPublicTransport::Line::Mode mode;
+        StatisticsModel::AggregateType type;
+    } static constexpr const lineModeMap[] = {
+        { KPublicTransport::Line::Air, StatisticsModel::Flight },
+        { KPublicTransport::Line::Boat, StatisticsModel::Boat },
+        { KPublicTransport::Line::Bus, StatisticsModel::Bus },
+        { KPublicTransport::Line::Coach, StatisticsModel::Bus },
+        { KPublicTransport::Line::Ferry, StatisticsModel::Boat },
+        { KPublicTransport::Line::Funicular, StatisticsModel::Train },
+        { KPublicTransport::Line::LocalTrain, StatisticsModel::Train },
+        { KPublicTransport::Line::LongDistanceTrain, StatisticsModel::Train },
+        { KPublicTransport::Line::Metro, StatisticsModel::Train },
+        { KPublicTransport::Line::RailShuttle, StatisticsModel::Train },
+        { KPublicTransport::Line::Shuttle, StatisticsModel::Bus },
+        { KPublicTransport::Line::Taxi, StatisticsModel::Car },
+        { KPublicTransport::Line::Train, StatisticsModel::Train },
+        { KPublicTransport::Line::Tramway, StatisticsModel::Train },
+        { KPublicTransport::Line::RideShare, StatisticsModel::Car },
+        // { KPublicTransport::Line::AerialLift, StatisticsModel::Train }, ### where to map this to?
+    };
+
+
+    for (const auto &jny :journey.sections()) {
+        StatisticsModel::AggregateType type = StatisticsModel::Total;
+        switch (jny.mode()) {
+            case KPublicTransport::JourneySection::Invalid:
+            case KPublicTransport::JourneySection::Walking:
+            case KPublicTransport::JourneySection::Transfer:
+            case KPublicTransport::JourneySection::Waiting:
+                break;
+            case KPublicTransport::JourneySection::PublicTransport:
+                for (const auto &m :lineModeMap) {
+                    if (m.mode == jny.route().line().mode()) {
+                        type = m.type;
+                    }
+                }
+                break;
+            case KPublicTransport::JourneySection::IndividualTransport:
+                if (jny.individualTransport().mode() == KPublicTransport::IndividualTransport::Car) {
+                    type = StatisticsModel::Car;
+                }
+                break;
+            case KPublicTransport::JourneySection::RentedVehicle:
+                if (jny.rentalVehicle().type() == KPublicTransport::RentalVehicle::Car) {
+                    type = StatisticsModel::Car;
+                }
+                break;
+        }
+        if (type == StatisticsModel::Total) {
+            continue;
+        }
+
+        statData[type][TripCount]++;
+        statData[type][Distance] += jny.distance();
+        statData[type][CO2] += jny.co2Emission();
+
+        statData[Total][TripCount]++;
+        statData[Total][Distance] += jny.distance();
+        statData[Total][CO2] += jny.co2Emission();
+    }
+}
+
 void StatisticsModel::recompute()
 {
     memset(m_statData, 0, AGGREGATE_TYPE_COUNT * STAT_TYPE_COUNT * sizeof(int));
@@ -263,7 +343,7 @@ void StatisticsModel::recompute()
     m_prevHotelCount = 0;
     m_countries.clear();
 
-    if (!m_resMgr || !m_tripGroupMgr) {
+    if (!m_resMgr || !m_tripGroupMgr || !m_transferMgr) {
         return;
     }
 
@@ -299,7 +379,7 @@ void StatisticsModel::recompute()
         }
 
         if (LocationUtil::isLocationChange(res)) {
-            computeStats(res, isPrev ? m_prevStatData : m_statData);
+            computeStats(batchId, res, isPrev ? m_prevStatData : m_statData);
         } else if (JsonLd::isA<LodgingReservation>(res)) {
             const auto hotel = res.value<LodgingReservation>();
             if (isPrev) {
@@ -309,16 +389,26 @@ void StatisticsModel::recompute()
             }
         }
 
+        for (const auto alignment : { Transfer::Before, Transfer::After}) {
+            if (const auto t = m_transferMgr->transfer(batchId, alignment); t.state() == Transfer::Selected) {
+                computeStats(t.journey(), isPrev ? m_prevStatData : m_statData);
+            }
+        }
+
         const auto tgId = m_tripGroupMgr->tripGroupIdForReservation(batchId);
-        if (!tgId.isEmpty()) {
+        if (isRelevantTripGroup(tgId)) {
             isPrev ? prevTripGroups.insert(tgId) : tripGroups.insert(tgId);
         }
 
         if (!isPrev) {
             auto c = LocationHelper::departureCountry(res);
-            if (!c.isEmpty()) m_countries.insert(c);
+            if (!c.isEmpty()) {
+                m_countries.insert(c);
+            }
             c = LocationHelper::destinationCountry(res);
-            if (!c.isEmpty()) m_countries.insert(c);
+            if (!c.isEmpty()) {
+                m_countries.insert(c);
+            }
         }
     }
 
@@ -328,6 +418,16 @@ void StatisticsModel::recompute()
     Q_EMIT changed();
 }
 
+bool StatisticsModel::isRelevantTripGroup(const QString &tgId) const
+{
+    const auto tg = m_tripGroupMgr->tripGroup(tgId);
+    const auto elems = tg.elements();
+    return std::any_of(elems.begin(), elems.end(), [this](const QString &elem) {
+        const auto res = m_resMgr->reservation(elem);
+        return LocationUtil::isLocationChange(res);
+    });
+}
+
 StatisticsItem::Trend StatisticsModel::trend(int current, int prev) const
 {
     if (!m_begin.isValid() || !m_end.isValid()) {
