@@ -12,12 +12,14 @@
 #include "livedatamanager.h"
 #include "locationhelper.h"
 #include "logging.h"
-#include "reservationhelper.h"
-#include "reservationmanager.h"
 #include "publictransport.h"
 #include "publictransportmatcher.h"
+#include "reservationhelper.h"
+#include "reservationmanager.h"
 #include "transfer.h"
 #include "transfermanager.h"
+#include "tripgroup.h"
+#include "tripgroupmanager.h"
 
 #include <KItinerary/BusTrip>
 #include <KItinerary/CalendarHandler>
@@ -25,8 +27,8 @@
 #include <KItinerary/Flight>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/LocationUtil>
-#include <KItinerary/SortUtil>
 #include <KItinerary/Reservation>
+#include <KItinerary/SortUtil>
 #include <KItinerary/Ticket>
 #include <KItinerary/TrainTrip>
 
@@ -41,12 +43,14 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QPointF>
-#include <QTimer>
 #include <QTimeZone>
+#include <QTimer>
 
-QTimer* TimelineDelegateController::s_currentTimer = nullptr;
+using namespace Qt::Literals;
+
+QTimer *TimelineDelegateController::s_currentTimer = nullptr;
 int TimelineDelegateController::s_progressRefCount = 0;
-QTimer* TimelineDelegateController::s_progressTimer = nullptr;
+QTimer *TimelineDelegateController::s_progressTimer = nullptr;
 
 using namespace KItinerary;
 
@@ -58,25 +62,27 @@ TimelineDelegateController::TimelineDelegateController(QObject *parent)
         s_currentTimer->setSingleShot(true);
         s_currentTimer->setTimerType(Qt::VeryCoarseTimer);
     }
-    connect(s_currentTimer, &QTimer::timeout, this, [this]() { checkForUpdate(m_batchId); });
+    connect(s_currentTimer, &QTimer::timeout, this, [this]() {
+        checkForUpdate(m_batchId);
+    });
 
     connect(this, &TimelineDelegateController::contentChanged, this, &TimelineDelegateController::connectionWarningChanged);
 }
 
 TimelineDelegateController::~TimelineDelegateController() = default;
 
-QObject* TimelineDelegateController::reservationManager() const
+ReservationManager *TimelineDelegateController::reservationManager() const
 {
     return m_resMgr;
 }
 
-void TimelineDelegateController::setReservationManager(QObject *resMgr)
+void TimelineDelegateController::setReservationManager(ReservationManager *resMgr)
 {
     if (m_resMgr == resMgr) {
         return;
     }
 
-    m_resMgr = qobject_cast<ReservationManager*>(resMgr);
+    m_resMgr = resMgr;
     Q_EMIT setupChanged();
     Q_EMIT contentChanged();
     Q_EMIT departureChanged();
@@ -94,18 +100,18 @@ void TimelineDelegateController::setReservationManager(QObject *resMgr)
     checkForUpdate(m_batchId);
 }
 
-QObject* TimelineDelegateController::liveDataManager() const
+LiveDataManager *TimelineDelegateController::liveDataManager() const
 {
     return m_liveDataMgr;
 }
 
-void TimelineDelegateController::setLiveDataManager(QObject* liveDataMgr)
+void TimelineDelegateController::setLiveDataManager(LiveDataManager *liveDataMgr)
 {
     if (m_liveDataMgr == liveDataMgr) {
         return;
     }
 
-    m_liveDataMgr = qobject_cast<LiveDataManager*>(liveDataMgr);
+    m_liveDataMgr = liveDataMgr;
     Q_EMIT setupChanged();
     Q_EMIT departureChanged();
     Q_EMIT arrivalChanged();
@@ -137,33 +143,33 @@ void TimelineDelegateController::setLiveDataManager(QObject* liveDataMgr)
     checkForUpdate(m_batchId);
 }
 
-QObject* TimelineDelegateController::transferManager() const
+TransferManager *TimelineDelegateController::transferManager() const
 {
     return m_transferMgr;
 }
 
-void TimelineDelegateController::setTransferManager(QObject *transferMgr)
+void TimelineDelegateController::setTransferManager(TransferManager *transferMgr)
 {
     if (m_transferMgr == transferMgr) {
         return;
     }
 
-    m_transferMgr = qobject_cast<TransferManager*>(transferMgr);
+    m_transferMgr = transferMgr;
     Q_EMIT setupChanged();
 }
 
-QObject* TimelineDelegateController::documentManager() const
+DocumentManager *TimelineDelegateController::documentManager() const
 {
     return m_documentMgr;
 }
 
-void TimelineDelegateController::setDocumentManager(QObject *documentMgr)
+void TimelineDelegateController::setDocumentManager(DocumentManager *documentMgr)
 {
     if (m_documentMgr == documentMgr) {
         return;
     }
 
-    m_documentMgr = qobject_cast<DocumentManager*>(documentMgr);
+    m_documentMgr = documentMgr;
     Q_EMIT setupChanged();
     Q_EMIT contentChanged();
 }
@@ -175,8 +181,9 @@ QString TimelineDelegateController::batchId() const
 
 void TimelineDelegateController::setBatchId(const QString &batchId)
 {
-    if (m_batchId == batchId)
+    if (m_batchId == batchId) {
         return;
+    }
 
     m_batchId = batchId;
     Q_EMIT batchIdChanged();
@@ -269,7 +276,7 @@ KPublicTransport::JourneySection TimelineDelegateController::journey() const
     return m_liveDataMgr->journey(m_batchId);
 }
 
-void TimelineDelegateController::checkForUpdate(const QString& batchId)
+void TimelineDelegateController::checkForUpdate(const QString &batchId)
 {
     if (!m_resMgr || m_batchId.isEmpty()) {
         setCurrent(false);
@@ -301,7 +308,7 @@ void TimelineDelegateController::checkForUpdate(const QString& batchId)
     }
 }
 
-QDateTime TimelineDelegateController::relevantStartDateTime(const QVariant &res) const
+QDateTime TimelineDelegateController::relevantStartDateTime(const QVariant &res)
 {
     auto startTime = SortUtil::startDateTime(res);
     if (JsonLd::isA<FlightReservation>(res)) {
@@ -316,7 +323,7 @@ QDateTime TimelineDelegateController::relevantStartDateTime(const QVariant &res)
     return startTime;
 }
 
-QDateTime TimelineDelegateController::liveStartDateTime(const QVariant& res) const
+QDateTime TimelineDelegateController::liveStartDateTime(const QVariant &res) const
 {
     if (m_liveDataMgr) {
         const auto dep = m_liveDataMgr->departure(m_batchId);
@@ -327,7 +334,7 @@ QDateTime TimelineDelegateController::liveStartDateTime(const QVariant& res) con
     return SortUtil::startDateTime(res);
 }
 
-QDateTime TimelineDelegateController::liveEndDateTime(const QVariant& res) const
+QDateTime TimelineDelegateController::liveEndDateTime(const QVariant &res) const
 {
     if (m_liveDataMgr) {
         const auto arr = m_liveDataMgr->arrival(m_batchId);
@@ -346,7 +353,7 @@ void TimelineDelegateController::scheduleNextUpdate(std::chrono::milliseconds ms
     s_currentTimer->start(ms);
 }
 
-void TimelineDelegateController::batchChanged(const QString& batchId)
+void TimelineDelegateController::batchChanged(const QString &batchId)
 {
     if (batchId != m_batchId || m_batchId.isEmpty()) {
         return;
@@ -386,9 +393,8 @@ QVariant TimelineDelegateController::previousLocation() const
 
     if (LocationUtil::isLocationChange(res)) {
         return LocationUtil::arrivalLocation(res);
-    } else {
-        return LocationUtil::location(res);
     }
+    return LocationUtil::location(res);
 }
 
 QDateTime TimelineDelegateController::effectiveEndTime() const
@@ -426,13 +432,15 @@ bool TimelineDelegateController::isPublicTransport() const
 
 static bool isJourneyCandidate(const QVariant &res)
 {
-    // TODO do we really need to constrain this to trains/buses? a long distance train can be a suitable alternative for a missed short distance flight for example
+    // TODO do we really need to constrain this to trains/buses? a long distance train can be a suitable alternative for a missed short distance flight for
+    // example
     return LocationUtil::isLocationChange(res) && (JsonLd::isA<TrainReservation>(res) || JsonLd::isA<BusReservation>(res));
 }
 
 static bool isLayover(const QVariant &res1, const QVariant &res2)
 {
-    if (!LocationUtil::isLocationChange(res1) || !LocationUtil::isLocationChange(res2) || ReservationHelper::isUnbound(res1) || ReservationHelper::isUnbound(res2)) {
+    if (!LocationUtil::isLocationChange(res1) || !LocationUtil::isLocationChange(res2) || ReservationHelper::isUnbound(res1)
+        || ReservationHelper::isUnbound(res2)) {
         return false;
     }
 
@@ -496,7 +504,7 @@ KPublicTransport::JourneyRequest TimelineDelegateController::journeyRequestFull(
 
 void TimelineDelegateController::applyJourney(const QVariant &journey, bool includeFollowing)
 {
-    if (!m_resMgr || m_batchId.isEmpty()) {
+    if (!m_resMgr || !m_tripGroupMgr || m_batchId.isEmpty()) {
         return;
     }
 
@@ -529,9 +537,14 @@ void TimelineDelegateController::applyJourney(const QVariant &journey, bool incl
     }
     qCDebug(Log) << "Affected batches:" << oldBatches;
 
+    // whatever we do here should not change trip grouping
+    const auto tgId = m_tripGroupMgr->tripGroupIdForReservation(m_batchId);
+    TripGroupingBlocker blocker(m_tripGroupMgr);
+
     // align sections with affected batches, by type, and insert/update accordingly
     auto it = oldBatches.begin();
     QString lastResId;
+    QStringList groupResIds;
     for (const auto &section : sections) {
         QVariant oldRes;
         if (it != oldBatches.end()) {
@@ -548,6 +561,7 @@ void TimelineDelegateController::applyJourney(const QVariant &journey, bool incl
                 m_resMgr->updateReservation(resId, res);
                 m_liveDataMgr->setJourney(resId, section);
             }
+            groupResIds.push_back(*it);
             ++it;
         } else {
             auto res = PublicTransport::reservationFromJourneySection(section);
@@ -562,9 +576,14 @@ void TimelineDelegateController::applyJourney(const QVariant &journey, bool incl
 
             const auto resId = m_resMgr->addReservation(res);
             m_liveDataMgr->setJourney(resId, section);
+            groupResIds.push_back(resId);
         }
     }
 
+    if (!tgId.isEmpty() && !groupResIds.isEmpty() && !m_tripGroupMgr->tripGroup(tgId).name().isEmpty()) {
+        m_tripGroupMgr->addToGroup(groupResIds, tgId);
+    }
+
     // remove left over reservations
     for (; it != oldBatches.end(); ++it) {
         m_resMgr->removeBatch(*it);
@@ -616,11 +635,11 @@ bool TimelineDelegateController::isCanceled() const
 
 static void mapArgumentsForLocation(QJSValue &args, const QVariant &location, QJSEngine *engine)
 {
-    args.setProperty(QStringLiteral("placeName"), LocationUtil::name(location));
-    args.setProperty(QStringLiteral("region"), LocationHelper::regionCode(location));
+    args.setProperty(u"placeName"_s, LocationUtil::name(location));
+    args.setProperty(u"region"_s, LocationHelper::regionCode(location));
 
     const auto geo = LocationUtil::geo(location);
-    args.setProperty(QStringLiteral("coordinate"), engine->toScriptValue(QPointF(geo.longitude(), geo.latitude())));
+    args.setProperty(u"coordinate"_s, engine->toScriptValue(QPointF(geo.longitude(), geo.latitude())));
 }
 
 struct CoachData {
@@ -639,9 +658,9 @@ static CoachData coachDataForReservation(const QVariant &res)
 
     CoachData data;
     data.coachName = seat.seatSection();
-    if (seat.seatingType() == QLatin1StringView("1")) {
+    if (seat.seatingType() == "1"_L1) {
         data.coachClass = KPublicTransport::VehicleSection::FirstClass;
-    } else if (seat.seatingType() == QLatin1StringView("2")) {
+    } else if (seat.seatingType() == "2"_L1) {
         data.coachClass = KPublicTransport::VehicleSection::SecondClass;
     }
     return data;
@@ -649,16 +668,13 @@ static CoachData coachDataForReservation(const QVariant &res)
 
 static QString platformSectionsForCoachData(const KPublicTransport::Stopover &stop, const CoachData &coach)
 {
-    KPublicTransport::PlatformLayout layouter;
     if (!coach.coachName.isEmpty()) {
-        return layouter.sectionsForVehicleSection(stop, coach.coachName);
-    } else if (coach.coachClass != KPublicTransport::VehicleSection::UnknownClass) {
-        return layouter.sectionsForClass(stop, coach.coachClass);
-    } else {
-        return layouter.sectionsForVehicle(stop);
+        return KPublicTransport::PlatformLayout::sectionsForVehicleSection(stop, coach.coachName);
     }
-
-    return {};
+    if (coach.coachClass != KPublicTransport::VehicleSection::UnknownClass) {
+        return KPublicTransport::PlatformLayout::sectionsForClass(stop, coach.coachClass);
+    }
+    return KPublicTransport::PlatformLayout::sectionsForVehicle(stop);
 }
 
 static void mapArgumentsForPt(QJSValue &args, QLatin1StringView prefix, const KPublicTransport::Stopover &stop, const CoachData &coach)
@@ -666,16 +682,16 @@ static void mapArgumentsForPt(QJSValue &args, QLatin1StringView prefix, const KP
     const auto platformName = stop.hasExpectedPlatform() ? stop.expectedPlatform() : stop.scheduledPlatform();
     if (!platformName.isEmpty()) {
         const auto sections = platformSectionsForCoachData(stop, coach);
-        args.setProperty(prefix + QLatin1StringView("PlatformName"), sections.isEmpty() ? platformName : (platformName + QLatin1Char(' ') + sections));
+        args.setProperty(prefix + "PlatformName"_L1, sections.isEmpty() ? platformName : (platformName + ' '_L1 + sections));
     }
 
     if (stop.route().line().mode() != KPublicTransport::Line::Unknown) {
-        args.setProperty(prefix + QLatin1StringView("PlatformMode"), PublicTransport::lineModeToPlatformMode(stop.route().line().mode()));
+        args.setProperty(prefix + "PlatformMode"_L1, PublicTransport::lineModeToPlatformMode(stop.route().line().mode()));
     }
 
-    const auto ifopt = stop.stopPoint().identifier(QStringLiteral("ifopt"));
+    const auto ifopt = stop.stopPoint().identifier(u"ifopt"_s);
     if (!ifopt.isEmpty()) {
-        args.setProperty(prefix + QLatin1StringView("PlatformIfopt"), ifopt);
+        args.setProperty(prefix + "PlatformIfopt"_L1, ifopt);
     }
 }
 
@@ -683,12 +699,12 @@ static void mapArrivalArgumesForRes(QJSValue &args, const QVariant &res)
 {
     if (JsonLd::isA<TrainReservation>(res)) {
         const auto trip = res.value<TrainReservation>().reservationFor().value<TrainTrip>();
-        args.setProperty(QStringLiteral("arrivalPlatformName"), trip.arrivalPlatform());
-        args.setProperty(QStringLiteral("arrivalPlatformMode"), KOSMIndoorMap::Platform::Rail);
+        args.setProperty(u"arrivalPlatformName"_s, trip.arrivalPlatform());
+        args.setProperty(u"arrivalPlatformMode"_s, KOSMIndoorMap::Platform::Rail);
     } else if (JsonLd::isA<BusReservation>(res)) {
         const auto trip = res.value<BusReservation>().reservationFor().value<BusTrip>();
-        args.setProperty(QStringLiteral("arrivalPlatformName"), trip.arrivalPlatform());
-        args.setProperty(QStringLiteral("arrivalPlatformMode"), KOSMIndoorMap::Platform::Bus);
+        args.setProperty(u"arrivalPlatformName"_s, trip.arrivalPlatform());
+        args.setProperty(u"arrivalPlatformMode"_s, KOSMIndoorMap::Platform::Bus);
     }
     // TODO there is no arrival gate property (yet)
 }
@@ -697,15 +713,15 @@ static void mapDepartureArgumentsForRes(QJSValue &args, const QVariant &res)
 {
     if (JsonLd::isA<TrainReservation>(res)) {
         const auto trip = res.value<TrainReservation>().reservationFor().value<TrainTrip>();
-        args.setProperty(QStringLiteral("departurePlatformName"), trip.departurePlatform());
-        args.setProperty(QStringLiteral("departurePlatformMode"), KOSMIndoorMap::Platform::Rail);
+        args.setProperty(u"departurePlatformName"_s, trip.departurePlatform());
+        args.setProperty(u"departurePlatformMode"_s, KOSMIndoorMap::Platform::Rail);
     } else if (JsonLd::isA<BusReservation>(res)) {
         const auto trip = res.value<BusReservation>().reservationFor().value<BusTrip>();
-        args.setProperty(QStringLiteral("departurePlatformName"), trip.departurePlatform());
-        args.setProperty(QStringLiteral("departurePlatformMode"), KOSMIndoorMap::Platform::Bus);
+        args.setProperty(u"departurePlatformName"_s, trip.departurePlatform());
+        args.setProperty(u"departurePlatformMode"_s, KOSMIndoorMap::Platform::Bus);
     } else if (JsonLd::isA<FlightReservation>(res)) {
         const auto flight = res.value<FlightReservation>().reservationFor().value<Flight>();
-        args.setProperty(QStringLiteral("departureGateName"), flight.departureGate());
+        args.setProperty(u"departureGateName"_s, flight.departureGate());
     }
 }
 
@@ -727,24 +743,24 @@ QJSValue TimelineDelegateController::arrivalMapArguments() const
     // arrival location
     mapArrivalArgumesForRes(args, res);
     const auto arr = arrival();
-    mapArgumentsForPt(args, QLatin1StringView("arrival"), arr, coachDataForReservation(res));
+    mapArgumentsForPt(args, "arrival"_L1, arr, coachDataForReservation(res));
 
     // arrival time
     auto arrTime = arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime();
     if (!arrTime.isValid()) {
         arrTime = SortUtil::endDateTime(res);
     }
-    args.setProperty(QStringLiteral("beginTime"), engine->toScriptValue(arrTime));
+    args.setProperty(u"beginTime"_s, engine->toScriptValue(arrTime));
     if (arrTime.timeSpec() == Qt::TimeZone) {
-        args.setProperty(QStringLiteral("timeZone"), QString::fromUtf8(arrTime.timeZone().id()));
+        args.setProperty(u"timeZone"_s, QString::fromUtf8(arrTime.timeZone().id()));
     }
 
     // look for departure for a following transfer
     const auto transfer = m_transferMgr->transfer(m_batchId, Transfer::After);
     if (transfer.state() == Transfer::Selected) {
         const auto dep = PublicTransport::firstTransportSection(transfer.journey()).departure();
-        mapArgumentsForPt(args, QLatin1StringView("departure"), dep, {});
-        args.setProperty(QStringLiteral("endTime"), engine->toScriptValue(dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime()));
+        mapArgumentsForPt(args, "departure"_L1, dep, {});
+        args.setProperty(u"endTime"_s, engine->toScriptValue(dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime()));
         return args;
     }
 
@@ -756,13 +772,13 @@ QJSValue TimelineDelegateController::arrivalMapArguments() const
     }
     mapDepartureArgumentsForRes(args, nextRes);
     const auto dep = m_liveDataMgr->departure(nextResId);
-    mapArgumentsForPt(args, QLatin1StringView("departure"), dep, coachDataForReservation(nextRes));
+    mapArgumentsForPt(args, "departure"_L1, dep, coachDataForReservation(nextRes));
 
     auto depTime = dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime();
     if (!depTime.isValid()) {
         depTime = SortUtil::startDateTime(nextRes);
     }
-    args.setProperty(QStringLiteral("endTime"), engine->toScriptValue(depTime));
+    args.setProperty(u"endTime"_s, engine->toScriptValue(depTime));
 
     return args;
 }
@@ -785,24 +801,24 @@ QJSValue TimelineDelegateController::departureMapArguments() const
     // departure location
     mapDepartureArgumentsForRes(args, res);
     const auto dep = departure();
-    mapArgumentsForPt(args, QLatin1StringView("departure"), dep, coachDataForReservation(res));
+    mapArgumentsForPt(args, "departure"_L1, dep, coachDataForReservation(res));
 
     // departure time
     auto depTime = dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime();
     if (!depTime.isValid()) {
         depTime = SortUtil::startDateTime(res);
     }
-    args.setProperty(QStringLiteral("endTime"), engine->toScriptValue(depTime));
+    args.setProperty(u"endTime"_s, engine->toScriptValue(depTime));
     if (depTime.timeSpec() == Qt::TimeZone) {
-        args.setProperty(QStringLiteral("timeZone"), QString::fromUtf8(depTime.timeZone().id()));
+        args.setProperty(u"timeZone"_s, QString::fromUtf8(depTime.timeZone().id()));
     }
 
     // look for arrival for a preceding transfer
     const auto transfer = m_transferMgr->transfer(m_batchId, Transfer::Before);
     if (transfer.state() == Transfer::Selected) {
         const auto arr = PublicTransport::lastTransportSection(transfer.journey()).arrival();
-        mapArgumentsForPt(args, QLatin1StringView("arrival"), arr, {});
-        args.setProperty(QStringLiteral("beginTime"), engine->toScriptValue(arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime()));
+        mapArgumentsForPt(args, "arrival"_L1, arr, {});
+        args.setProperty(u"beginTime"_s, engine->toScriptValue(arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime()));
         return args;
     }
 
@@ -814,13 +830,13 @@ QJSValue TimelineDelegateController::departureMapArguments() const
     }
     mapArrivalArgumesForRes(args, prevRes);
     const auto arr = m_liveDataMgr->arrival(prevResId);
-    mapArgumentsForPt(args, QLatin1StringView("arrival"), arr, coachDataForReservation(prevRes));
+    mapArgumentsForPt(args, "arrival"_L1, arr, coachDataForReservation(prevRes));
 
     auto arrTime = arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime();
     if (!arrTime.isValid()) {
         arrTime = SortUtil::endDateTime(prevRes);
     }
-    args.setProperty(QStringLiteral("beginTime"), engine->toScriptValue(arrTime));
+    args.setProperty(u"beginTime"_s, engine->toScriptValue(arrTime));
 
     return args;
 }
@@ -859,11 +875,11 @@ QJSValue TimelineDelegateController::mapArguments() const
     auto transfer = m_transferMgr->transfer(m_batchId, Transfer::Before);
     if (transfer.state() == Transfer::Selected) {
         const auto arr = PublicTransport::lastTransportSection(transfer.journey()).arrival();
-        mapArgumentsForPt(args, QLatin1StringView("arrival"), arr, {});
+        mapArgumentsForPt(args, "arrival"_L1, arr, {});
         beginDt = std::max(arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime(), beginDt);
     }
 
-    args.setProperty(QStringLiteral("beginTime"), engine->toScriptValue(beginDt));
+    args.setProperty(u"beginTime"_s, engine->toScriptValue(beginDt));
 
     auto endDt = SortUtil::endDateTime(res);
     if (endDt.isValid()) {
@@ -874,7 +890,7 @@ QJSValue TimelineDelegateController::mapArguments() const
     transfer = m_transferMgr->transfer(m_batchId, Transfer::After);
     if (transfer.state() == Transfer::Selected) {
         const auto dep = PublicTransport::firstTransportSection(transfer.journey()).departure();
-        mapArgumentsForPt(args, QLatin1StringView("departure"), dep, {});
+        mapArgumentsForPt(args, "departure"_L1, dep, {});
         const auto depDt = dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime();
         endDt = endDt.isValid() ? std::min(endDt, depDt) : depDt;
     }
@@ -897,7 +913,7 @@ QJSValue TimelineDelegateController::mapArguments() const
     }
 
     if (endDt.isValid()) {
-        args.setProperty(QStringLiteral("endTime"), engine->toScriptValue(endDt));
+        args.setProperty(u"endTime"_s, engine->toScriptValue(endDt));
     }
 
     return args;
@@ -941,7 +957,7 @@ static void applyVehicleLayout(KPublicTransport::Stopover &stop, const KPublicTr
     }
 }
 
-void TimelineDelegateController::setVehicleLayout(const KPublicTransport::Stopover& stopover, bool arrival)
+void TimelineDelegateController::setVehicleLayout(const KPublicTransport::Stopover &stopover, bool arrival)
 {
     auto jny = journey();
     if (!arrival) {
@@ -1001,4 +1017,13 @@ QStringList TimelineDelegateController::documentIds() const
     return result;
 }
 
+QVariant TimelineDelegateController::reservation() const
+{
+    if (!m_resMgr || m_batchId.isEmpty()) {
+        return {};
+    }
+
+    return m_resMgr->reservation(m_batchId);
+}
+
 #include "moc_timelinedelegatecontroller.cpp"
