@@ -25,15 +25,33 @@ using namespace KItinerary;
 
 static TimelineElement::ElementType elementType(const QVariant &res)
 {
-    if (JsonLd::isA<FlightReservation>(res)) { return TimelineElement::Flight; }
-    if (JsonLd::isA<LodgingReservation>(res)) { return TimelineElement::Hotel; }
-    if (JsonLd::isA<TrainReservation>(res)) { return TimelineElement::TrainTrip; }
-    if (JsonLd::isA<BusReservation>(res)) { return TimelineElement::BusTrip; }
-    if (JsonLd::isA<BoatReservation>(res)) { return TimelineElement::BoatTrip; }
-    if (JsonLd::isA<FoodEstablishmentReservation>(res)) { return TimelineElement::Restaurant; }
-    if (JsonLd::isA<TouristAttractionVisit>(res)) { return TimelineElement::TouristAttraction; }
-    if (JsonLd::isA<EventReservation>(res)) { return TimelineElement::Event; }
-    if (JsonLd::isA<RentalCarReservation>(res)) { return TimelineElement::CarRental; }
+    if (JsonLd::isA<FlightReservation>(res)) {
+        return TimelineElement::Flight;
+    }
+    if (JsonLd::isA<LodgingReservation>(res)) {
+        return TimelineElement::Hotel;
+    }
+    if (JsonLd::isA<TrainReservation>(res)) {
+        return TimelineElement::TrainTrip;
+    }
+    if (JsonLd::isA<BusReservation>(res)) {
+        return TimelineElement::BusTrip;
+    }
+    if (JsonLd::isA<BoatReservation>(res)) {
+        return TimelineElement::BoatTrip;
+    }
+    if (JsonLd::isA<FoodEstablishmentReservation>(res)) {
+        return TimelineElement::Restaurant;
+    }
+    if (JsonLd::isA<TouristAttractionVisit>(res)) {
+        return TimelineElement::TouristAttraction;
+    }
+    if (JsonLd::isA<EventReservation>(res)) {
+        return TimelineElement::Event;
+    }
+    if (JsonLd::isA<RentalCarReservation>(res)) {
+        return TimelineElement::CarRental;
+    }
     return {};
 }
 
@@ -47,7 +65,7 @@ TimelineElement::TimelineElement(TimelineModel *model, TimelineElement::ElementT
 {
 }
 
-TimelineElement::TimelineElement(TimelineModel *model, const QString& resId, const QVariant& res, TimelineElement::RangeType rt)
+TimelineElement::TimelineElement(TimelineModel *model, const QString &resId, const QVariant &res, TimelineElement::RangeType rt)
     : dt(relevantDateTime(res, rt))
     , elementType(::elementType(res))
     , rangeType(rt)
@@ -67,7 +85,7 @@ TimelineElement::TimelineElement(TimelineModel *model, const ::Transfer &transfe
 
 static bool operator<(TimelineElement::RangeType lhs, TimelineElement::RangeType rhs)
 {
-    static const int order_map[] = { 1, 0, 2 };
+    static const int order_map[] = {1, 0, 2};
     return order_map[lhs] < order_map[rhs];
 }
 
@@ -97,37 +115,36 @@ bool TimelineElement::operator==(const TimelineElement &other) const
     }
 
     switch (elementType) {
-        case Transfer:
-        {
-            const auto lhsT = m_content.value<::Transfer>();
-            const auto rhsT = other.m_content.value<::Transfer>();
-            return lhsT.alignment() == rhsT.alignment();
-        }
-        default:
-            return dt == other.dt;
+    case Transfer: {
+        const auto lhsT = m_content.value<::Transfer>();
+        const auto rhsT = other.m_content.value<::Transfer>();
+        return lhsT.alignment() == rhsT.alignment();
+    }
+    default:
+        return dt == other.dt;
     }
 }
 
 bool TimelineElement::isReservation() const
 {
     switch (elementType) {
-        case Flight:
-        case TrainTrip:
-        case CarRental:
-        case BusTrip:
-        case BoatTrip:
-        case Restaurant:
-        case TouristAttraction:
-        case Event:
-        case Hotel:
-            return true;
-        case Undefined:
-        case TodayMarker:
-        case TripGroup:
-        case WeatherForecast:
-        case LocationInfo:
-        case Transfer:
-            return false;
+    case Flight:
+    case TrainTrip:
+    case CarRental:
+    case BusTrip:
+    case BoatTrip:
+    case Restaurant:
+    case TouristAttraction:
+    case Event:
+    case Hotel:
+        return true;
+    case Undefined:
+    case TodayMarker:
+    case TripGroup:
+    case WeatherForecast:
+    case LocationInfo:
+    case Transfer:
+        return false;
     }
 
     Q_UNREACHABLE();
@@ -150,7 +167,7 @@ QVariant TimelineElement::content() const
     return m_content;
 }
 
-void TimelineElement::setContent(const QVariant& content)
+void TimelineElement::setContent(const QVariant &content)
 {
     m_content = content;
 }
@@ -185,26 +202,26 @@ bool TimelineElement::isLocationChange() const
 bool TimelineElement::isTimeBoxed() const
 {
     switch (elementType) {
-        case Undefined:
-        case TodayMarker:
-        case TripGroup:
-        case WeatherForecast:
-        case LocationInfo:
-            return false;
-        case Transfer:
-            return m_content.value<::Transfer>().state() == Transfer::Selected;
-        case Flight:
-        case TrainTrip:
-        case BusTrip:
-        case BoatTrip:
-            return true;
-        case Hotel:
-        case CarRental:
-            return false;
-        case Restaurant:
-        case TouristAttraction:
-        case Event:
-            return SortUtil::endDateTime(m_model->m_resMgr->reservation(batchId())).isValid();
+    case Undefined:
+    case TodayMarker:
+    case TripGroup:
+    case WeatherForecast:
+    case LocationInfo:
+        return false;
+    case Transfer:
+        return m_content.value<::Transfer>().state() == Transfer::Selected;
+    case Flight:
+    case TrainTrip:
+    case BusTrip:
+    case BoatTrip:
+        return true;
+    case Hotel:
+    case CarRental:
+        return false;
+    case Restaurant:
+    case TouristAttraction:
+    case Event:
+        return SortUtil::endDateTime(m_model->m_resMgr->reservation(batchId())).isValid();
     }
     return false;
 }
@@ -212,23 +229,23 @@ bool TimelineElement::isTimeBoxed() const
 bool TimelineElement::isInformational() const
 {
     switch (elementType) {
-        case Undefined:
-        case TodayMarker:
-        case TripGroup:
-        case WeatherForecast:
-        case LocationInfo:
-            return true;
-        case Transfer:
-        case Flight:
-        case TrainTrip:
-        case BusTrip:
-        case BoatTrip:
-        case Hotel:
-        case CarRental:
-        case Restaurant:
-        case TouristAttraction:
-        case Event:
-            return false;
+    case Undefined:
+    case TodayMarker:
+    case TripGroup:
+    case WeatherForecast:
+    case LocationInfo:
+        return true;
+    case Transfer:
+    case Flight:
+    case TrainTrip:
+    case BusTrip:
+    case BoatTrip:
+    case Hotel:
+    case CarRental:
+    case Restaurant:
+    case TouristAttraction:
+    case Event:
+        return false;
     }
     Q_UNREACHABLE();
 }
@@ -261,14 +278,25 @@ static KPublicTransport::Location destinationOfJourney(const KPublicTransport::J
     const auto locName = loc.name();
 
     // "anonymous" location with the coordinates as name
-    if (std::none_of(locName.begin(), locName.end(), [](QChar c) { return c.isLetter(); }) && !prevLoc.name().isEmpty()) {
+    if (std::none_of(locName.begin(),
+                     locName.end(),
+                     [](QChar c) {
+                         return c.isLetter();
+                     })
+        && !prevLoc.name().isEmpty()) {
         return prevLoc;
     }
 
     // propagate address information from the last stop to the final destination
-    if (loc.locality().isEmpty()) { loc.setLocality(prevLoc.locality()); }
-    if (loc.region().isEmpty()) { loc.setRegion(prevLoc.region()); }
-    if (loc.country().isEmpty()) { loc.setLocality(prevLoc.country()); }
+    if (loc.locality().isEmpty()) {
+        loc.setLocality(prevLoc.locality());
+    }
+    if (loc.region().isEmpty()) {
+        loc.setRegion(prevLoc.region());
+    }
+    if (loc.country().isEmpty()) {
+        loc.setLocality(prevLoc.country());
+    }
 
     return loc;
 }
