@@ -610,7 +610,7 @@ void TimelineModel::updateInformationElements()
         }
         auto searchWindowEnd = now().addDays(DST_DAYS_AFTER);
         if (m_tripGroup.endDateTime().isValid()) {
-            searchWindowEnd = std::min(searchWindowEnd, m_tripGroup.beginDateTime());
+            searchWindowEnd = std::min(searchWindowEnd, m_tripGroup.endDateTime());
         }
 
         for (auto it = m_elements.begin(); it != m_elements.end(); ++it) {
@@ -741,7 +741,7 @@ void TimelineModel::updateWeatherElements()
             if ((*it2).dt >= endTime) {
                 break;
             }
-            if ((*it2).isLocationChange()) {
+            if ((*it2).isLocationChange() && !(*it2).isCanceled()) {
                 // exclude the actual travel time from forecast ranges
                 endTime = std::min(endTime, (*it2).dt);
                 nextStartTime = std::max(endTime, (*it2).endDateTime());
