@@ -12,7 +12,6 @@
 
 #include <KItinerary/SortUtil>
 
-#include <QDateTime>
 #include <QDebug>
 #include <QFile>
 #include <QJsonArray>
@@ -53,9 +52,15 @@ void TripGroup::setIsAutomaticallyGrouped(bool automatic)
     m_automaticallyGrouped = automatic;
 }
 
-QList<QString> TripGroup::elements() const { return m_elements; }
+QList<QString> TripGroup::elements() const
+{
+    return m_elements;
+}
 
-void TripGroup::setElements(const QList<QString> &elems) { m_elements = elems; }
+void TripGroup::setElements(const QList<QString> &elems)
+{
+    m_elements = elems;
+}
 
 QJsonObject TripGroup::toJson(const TripGroup &group)
 {
@@ -104,7 +109,7 @@ bool TripGroup::load(const QString &path)
     }
 
     *this = TripGroup::fromJson(JsonIO::read(f.readAll()).toObject());
-    return m_elements.size() >= 2;
+    return !m_name.isEmpty();
 }
 
 void TripGroup::store(const QString &path) const
