@@ -8,17 +8,18 @@
 
 #include "eventdata.h"
 
-#include "kandroidextras/jniobject.h"
+#include "kandroidextras/androidtypes.h"
+#include "kandroidextras/javatypes.h"
 #include "kandroidextras/jnimethod.h"
+#include "kandroidextras/jniobject.h"
 #include "kandroidextras/jniproperty.h"
 #include "kandroidextras/jnitypes.h"
-#include "kandroidextras/javatypes.h"
-#include "kandroidextras/androidtypes.h"
 
 JNI_TYPE(org, kde, kcalendarcore, Calendar)
 
 /** JNI wrapper for the CalendarPlugin class. */
-class JniCalendar {
+class JniCalendar
+{
     JNI_OBJECT(JniCalendar, org::kde::kcalendarcore::Calendar)
 public:
     JNI_CONSTRUCTOR(JniCalendar, KAndroidExtras::android::content::Context, jlong)
