@@ -9,18 +9,19 @@
 
 #include "kandroidextras_export.h"
 
-namespace KAndroidExtras {
+namespace KAndroidExtras
+{
 
 class Intent;
 
 /** Methods around android.app.Activity. */
 namespace Activity
 {
-    /** Returns the Intent that started the activity. */
-    KANDROIDEXTRAS_EXPORT Intent getIntent();
+/** Returns the Intent that started the activity. */
+KANDROIDEXTRAS_EXPORT Intent getIntent();
 
-    /** Same as QtAndroid::startActivity(), but with exception handling. */
-    KANDROIDEXTRAS_EXPORT bool startActivity(const Intent &intent, int receiverRequestCode); // TODO add callback arg
+/** Same as QtAndroid::startActivity(), but with exception handling. */
+KANDROIDEXTRAS_EXPORT bool startActivity(const Intent &intent, int receiverRequestCode); // TODO add callback arg
 }
 
 }
